#AUTH
'''
   Sun Softwares Module v1 
   Module to display objects.

'''
import sys
sys.path.append('/path/to/sunsketch')
#imports
import tkinter as tk
import os
import sunx2_helper as sh






def draw(put ,title="Display" , size="device" , font_bg="white" , font=20 , weight="normal" , color = ['white','black']):
	'''
	Displays a result 
	uses Display('str' , title="display" ) 
	supported args title ( window title ) , size (small , medium, compat , smaller , device , huge or 120x233 format) , weight = bold , italic , normal , color = [windowcolor , textcolor] , font = font size
	
	'''
	window = tk.Tk()
	window.configure(background=color[0])
	window.title(title)
	try:
		size=sh.returnsize(size)
	except:
		print("Size is error")
		return
	window.minsize(size[0],size[1])
	l1 = tk.Label(window,text=put,fg=color[1] , bg = font_bg , font='-size {0} -weight {1}'.format(font,weight))
	l1.pack() 
	window.mainloop()

ob , fonts , weights , paddings , colors, font_colors = [] , [] , [] , [] , [] , []


def add(item,color="default",font=10,padding=10,weight='normal',font_color='black'):
	global ob
	global fonts
	global paddings
	global weights
	global colors
	global font_colors

	ob = ob + [item]
	colors = colors + [color]
	fonts = fonts + [font]
	paddings = paddings +  [padding]
	weights = weights + [weight]
	font_colors = font_colors + [font_color]
def show(title="Showcase",size="device",color="white"):
	root = tk.Tk()
	gui = sh.Show(root,size=size,color=color,title=title)
	for item in ob:
		posi = ob.index(item)
		gui.add(item,padding=paddings[posi],color=colors[posi],weight=weights[posi],font=fonts[posi],font_color=font_colors[posi])
	root.mainloop()
		
		


if __name__=="__main__":
	print('A Graphics display script created by sun')


	
	
	
	
	
	
	
	
	
	






from distutils.core import setup
setup(
  name = 'sunsketch',
  packages = ['sunsketch'], # this must be the same as the name above
  version = '0.2b',
  description = 'A simple Graphical display tool',
  author = 'Sun',
  author_email = 'xxsunxxrose@gmail.com',
  url = 'https://github.com/sunx2/sketch', # use the URL to the github repo
  keywords = ['print', 'beautiful', 'display','sun'], # arbitrary keywords
  classifiers = [],
)



import tkinter as tk
import sys , os


def returnsize(size):
	if size == "small":
		return [400,400]
	elif size == "medium":
		return [600,600]
	elif size == "huge":
		return [800,800]
	elif size == "smaller":
		return [250,250]
	elif size == "compat":
		return [100,100]
	elif size == "device":
		return [250,300]
	else:
		return [int(size.split('x')[0]),int(size.split('x')[1])]



class Show(object):
	def __init__(self,master,size="device",color='white',title="Showcase"):
		self.master = master
		self.color=color
		master.minsize(returnsize(size)[0],returnsize(size)[1])
		master.configure(background=color)
		master.title(title)
	def add(self,text,padding=10,color='default',weight='normal',font=10,font_color='black'):
		col = self.color if color=="default" else color
		label = tk.Label(self.master,fg=font_color,text=text,pady=padding,bg=col,font="-size {0} -weight {1}".format(font,weight))
		label.pack()
